# oneNeuron
oneNeuron implementation


##How to use this
```python
   from Neuron.perceptron import Perceptron
   ## get X and y and then use this commands
   model=Perceptron(eta=eta,epochs=epochs)
   model.fit(X,y)
   ```





# References-
[python official docs](https://packaging.python.org/tutorials/packaging-projects/)
[github docs for github actions](https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registries)